<?php

namespace Drupal\monarch_entity_pdf\Controller;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Session\AccountInterface;
use Monarch\PdfResponse;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\HttpKernel\Exception\NotFoundHttpException;

/**
 * Returns responses for S5 Calculators routes.
 */
class EntityPdfController extends ControllerBase {

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container): self {
    $instance = new static();

    $instance->entityTypeManager = $container->get('entity_type.manager');

    return $instance;
  }

  /**
   * Check access of the route.
   */
  public function access(AccountInterface $account, $type = NULL, $id = NULL) {
    if (
      !$type ||
      !$id ||
      !($storage = $this->entityTypeManager->getStorage($type)) ||
      !($entity = $storage->load($id)) ||
      !($entity instanceof EntityInterface)
    ) {
      throw new NotFoundHttpException();
    }

    return $entity->access('view', $account) ? AccessResult::allowed() : AccessResult::forbidden();
  }

  /**
   * Builds the response.
   */
  public function content($type = NULL, $id = NULL) : Response {
    $storage = $this->entityTypeManager->getStorage($type);
    $entity = $storage->load($id);
    $build['content'] = $this->entityTypeManager->getViewBuilder($type)->view($entity, 'pdf');

    return new PdfResponse($build);
  }

}
